StartSessionInput

Struct StartSessionInput 

#[non_exhaustive]
pub struct StartSessionInput { pub description: Option<String>, pub work_group: Option<String>, pub engine_configuration: Option<EngineConfiguration>, pub execution_role: Option<String>, pub monitoring_configuration: Option<MonitoringConfiguration>, pub notebook_version: Option<String>, pub session_idle_timeout_in_minutes: Option<i32>, pub client_request_token: Option<String>, pub tags: Option<Vec<Tag>>, pub copy_work_group_tags: Option<bool>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
description: Option<String>

The session description.

work_group: Option<String>

The workgroup to which the session belongs.

engine_configuration: Option<EngineConfiguration>

Contains engine data processing unit (DPU) configuration settings and parameter mappings.

execution_role: Option<String>

The ARN of the execution role used to access user resources for Spark sessions and Identity Center enabled workgroups. This property applies only to Spark enabled workgroups and Identity Center enabled workgroups.

monitoring_configuration: Option<MonitoringConfiguration>

Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.

notebook_version: Option<String>

The notebook version. This value is supplied automatically for notebook sessions in the Athena console and is not required for programmatic session access. The only valid notebook version is Athena notebook version 1. If you specify a value for NotebookVersion, you must also specify a value for NotebookId. See EngineConfiguration$AdditionalConfigs.

session_idle_timeout_in_minutes: Option<i32>

The idle timeout in minutes for the session.

client_request_token: Option<String>

A unique case-sensitive string used to ensure the request to create the session is idempotent (executes only once). If another StartSessionRequest is received, the same response is returned and another session is not created. If a parameter has changed, an error is returned.

This token is listed as not required because Amazon Web Services SDKs (for example the Amazon Web Services SDK for Java) auto-generate the token for users. If you are not using the Amazon Web Services SDK or the Amazon Web Services CLI, you must provide this token or the action will fail.

tags: Option<Vec<Tag>>

A list of comma separated tags to add to the session that is created.

copy_work_group_tags: Option<bool>

Copies the tags from the Workgroup to the Session when.

Implementations

Source

impl StartSessionInput

pub fn description(&self) -> Option<&str>

The session description.

pub fn work_group(&self) -> Option<&str>

The workgroup to which the session belongs.

pub fn engine_configuration(&self) -> Option<&EngineConfiguration>

Contains engine data processing unit (DPU) configuration settings and parameter mappings.

pub fn execution_role(&self) -> Option<&str>

The ARN of the execution role used to access user resources for Spark sessions and Identity Center enabled workgroups. This property applies only to Spark enabled workgroups and Identity Center enabled workgroups.

pub fn monitoring_configuration(&self) -> Option<&MonitoringConfiguration>

Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.

pub fn notebook_version(&self) -> Option<&str>

The notebook version. This value is supplied automatically for notebook sessions in the Athena console and is not required for programmatic session access. The only valid notebook version is Athena notebook version 1. If you specify a value for NotebookVersion, you must also specify a value for NotebookId. See EngineConfiguration$AdditionalConfigs.

pub fn session_idle_timeout_in_minutes(&self) -> Option<i32>

The idle timeout in minutes for the session.

pub fn client_request_token(&self) -> Option<&str>

A unique case-sensitive string used to ensure the request to create the session is idempotent (executes only once). If another StartSessionRequest is received, the same response is returned and another session is not created. If a parameter has changed, an error is returned.

This token is listed as not required because Amazon Web Services SDKs (for example the Amazon Web Services SDK for Java) auto-generate the token for users. If you are not using the Amazon Web Services SDK or the Amazon Web Services CLI, you must provide this token or the action will fail.

pub fn tags(&self) -> &[Tag]

A list of comma separated tags to add to the session that is created.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().

pub fn copy_work_group_tags(&self) -> Option<bool>

Copies the tags from the Workgroup to the Session when.

Source

impl StartSessionInput

pub fn builder() -> StartSessionInputBuilder

Creates a new builder-style object to manufacture StartSessionInput.